@@ -20,6 +20,7 @@ from .literals import (
     ArtifactPackagingType,
     ArtifactsTypeType,
     AuthTypeType,
+    BucketOwnerAccessType,
     BuildBatchPhaseTypeType,
     BuildPhaseTypeType,
     CacheModeType,
@@ -312,6 +313,7 @@ BuildArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
+        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -1249,6 +1251,7 @@ _OptionalProjectArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
+        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -1565,6 +1568,7 @@ _OptionalS3LogsConfigTypeDef = TypedDict(
     {
         "location": str,
         "encryptionDisabled": bool,
+        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
